==> nextcloud-app-mail-0.15.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/mail/l10n/ja.js <==
OC.L10N.register(
    "mail",
    {
    "Mail" : "メール",
    "Inbox" : "受信箱",
    "Sent" : "送信",
    "Drafts" : "草稿",
    "Archive" : "アーカイブ",
    "Trash" : "ゴミ箱",
    "Junk" : "迷惑メール",
    "All" : "すべて",
    "Favorites" : "お気に入り",
    "Auto detect failed. Please use manual mode." : "自動判別に失敗しました。手動モードをご利用ください。",
    "Updating account failed: " : "アカウントの更新に失敗：",
    "Creating account failed: " : "アカウント作成に失敗:",
    "Delete permanently" : "完全に削除する",
    "IMAP web client" : "IMAPウェブクライアント",
    "Easy to use email client which connects to your mail server via IMAP and SMTP." : "IMAPとSMTP経由であなたのメールサーバーに接続する使いやすい電子メールクライアント。",
    "Auto" : "自動",
    "Name" : "名前",
    "Mail Address" : "メールアドレス",
    "Password" : "パスワード",
    "Manual" : "手動",
    "IMAP Settings" : "IMAP設定",
    "IMAP Host" : "IMAPホスト",
    "IMAP Security" : "IMAPセキュリティ",
    "None" : "なし",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "IMAP Port" : "IMAPポート",
    "IMAP User" : "IMAPユーザー",
    "IMAP Password" : "IMAPパスワード",
    "SMTP Settings" : "SMTP設定",
    "SMTP Host" : "SMTPホスト",
    "SMTP Security" : "SMTPセキュリティ",
    "SMTP Port" : "SMTPポート",
    "SMTP User" : "SMTPユーザー",
    "SMTP Password" : "SMTPパスワード",
    "Save" : "保存",
    "Connect" : "接続",
    "Add mail account" : "メールアカウントを追加",
    "Use Gravatar and favicon avatars" : "Gravatarとfaviconのアバターを使用する",
    "Keyboard shortcuts" : "キーボード ショートカット",
    "from" : "差出人",
    "to" : "宛先",
    "cc" : "cc",
    "bcc" : "bcc",
    "Subject" : "件名",
    "Saving draft …" : "下書きを保存しています",
    "Draft saved" : "下書きを保存しました。",
    "Uploading attachments …" : "添付ファイルをアップロード",
    "Sending …" : "送信中 …",
    "Go back" : "戻る",
    "Retry" : "再試行",
    "Message sent!" : "へメッセージを送信しました！",
    "Write another message" : "他のメッセージを書く",
    "Send" : "送信",
    "Uploading {percent}% …" : "アップロード中 {percent}% …",
    "Upload attachment" : "添付ファイルをアップロードする",
    "Add attachment from Files" : "ファイルから添付ファイルの追加",
    "Choose a file to add as attachment" : "添付として追加するファイルを選択",
    "No messages in this folder" : "このフォルダーにメッセージはありません",
    "Draft: " : "下書き",
    "Mark read" : "既読にする",
    "Mark unread" : "未読にする",
    "Delete" : "削除",
    "Report this bug" : "バグを報告",
    "Loading messages" : "メッセージの読み込み中",
    "Not found" : "見つかりませんでした",
    "Could not load your message" : "あなたのメッセージを読み込めませんでした",
    "Import into calendar" : "カレンダーにインポート",
    "Download attachment" : "添付ファイルをダウンロード",
    "Save to Files" : "ファイルに保存",
    "Choose a folder to store the attachment in" : "添付ファイルを保存するフォルダーを選択",
    "Save all to Files" : "すべてファイルに保存",
    "The images have been blocked to protect your privacy." : "画像はあなたのプライバシーを守るためにブロックされています。",
    "New message" : "新規メッセージ",
    "Settings" : "設定",
    "Edit" : "編集",
    "Show all folders" : "すべてのフォルダーを表示",
    "Collapse folders" : "すべて展開",
    "Could not load your draft" : "下書きを読み込めませんでした",
    "No message selected" : "メッセージが選択されていません。",
    "Account Settings" : "アカウント設定",
    "Speed up your Mail experience with these quick shortcuts." : "ショートカットであなたのメール操作をスピードアップしてください。",
    "Compose new message" : "新しいメッセージを作成する",
    "Newer message" : "新しいメッセージ",
    "Older message" : "古いメッセージ",
    "Toggle star" : "スターを切り替え",
    "Toggle unread" : "未読を切り替え",
    "Search" : "検索",
    "Refresh" : "同期",
    "Connect your mail account" : "あなたのメールアカウントに接続",
    "{from}\n{subject}" : "{from}\n{subject}",
    "_%n new message \nfrom {from}_::_%n new messages \nfrom {from}_" : ["%n個の新しいメッセージ\nfrom{from}"],
    "Nextcloud Mail" : "Nextcloud メール",
    "All inboxes" : "すべての受信トレイ",
    "Could not load {tag}{name}{endtag}" : "{tag} {name} {endtag}を読み込めませんでした",
    "There was a problem loading {tag}{name}{endtag}" : "{tag}{name}{endtag} の読み込み中に問題が発生しました",
    "Could not load the desired message" : "目的のメッセージを読み込めませんでした",
    "Could not load the message" : "メッセージを読み込めませんでした",
    "Error loading message" : "メッセージ読み込みエラー",
    "Forwarding to %s" : "%s への転送",
    "Click here if you are not automatically redirected within the next few seconds." : "数秒以内に自動的にリダイレクトされない場合は、ここをクリックしてください。",
    "Redirect" : "リダイレクト",
    "The link leads to %s" : "リンクが %s につながります",
    "If you don’t want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "ページを開きたくない場合は、<a href=\"%s\">メール</a> に戻ることができます。",
    "Continue to %s" : "%s にリダイレクトする"
},
"nplurals=1; plural=0;");

==> nextcloud-app-mail-0.15.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/mail/l10n/ja.js <==
OC.L10N.register(
    "mail",
    {
    "Mail" : "メール",
    "Inbox" : "受信箱",
    "Sent" : "送信",
    "Drafts" : "草稿",
    "Archive" : "アーカイブ",
    "Trash" : "ゴミ箱",
    "Junk" : "迷惑メール",
    "All" : "すべて",
    "Favorites" : "お気に入り",
    "Auto detect failed. Please use manual mode." : "自動判別に失敗しました。手動モードをご利用ください。",
    "Updating account failed: " : "アカウントの更新に失敗：",
    "Creating account failed: " : "アカウント作成に失敗:",
    "Delete permanently" : "完全に削除する",
    "IMAP web client" : "IMAPウェブクライアント",
    "Easy to use email client which connects to your mail server via IMAP and SMTP." : "IMAPとSMTP経由であなたのメールサーバーに接続する使いやすい電子メールクライアント。",
    "Auto" : "自動",
    "Name" : "名前",
    "Mail Address" : "メールアドレス",
    "Password" : "パスワード",
    "Manual" : "手動",
    "IMAP Settings" : "IMAP設定",
    "IMAP Host" : "IMAPホスト",
    "IMAP Security" : "IMAPセキュリティ",
    "None" : "なし",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "IMAP Port" : "IMAPポート",
    "IMAP User" : "IMAPユーザー",
    "IMAP Password" : "IMAPパスワード",
    "SMTP Settings" : "SMTP設定",
    "SMTP Host" : "SMTPホスト",
    "SMTP Security" : "SMTPセキュリティ",
    "SMTP Port" : "SMTPポート",
    "SMTP User" : "SMTPユーザー",
    "SMTP Password" : "SMTPパスワード",
    "Save" : "保存",
    "Connect" : "接続",
    "Add mail account" : "メールアカウントを追加",
    "Use Gravatar and favicon avatars" : "Gravatarとfaviconのアバターを使用する",
    "Keyboard shortcuts" : "キーボード ショートカット",
    "Looking for a way to encrypt your emails? Install the Mailvelope browser extension!" : "メールを暗号化する方法をお探しですか?Mailvelopeブラウザー拡張をインストールしてください。",
    "from" : "差出人",
    "to" : "宛先",
    "+ cc/bcc" : "+ cc/bcc",
    "cc" : "cc",
    "bcc" : "bcc",
    "Subject" : "件名",
    "Note that the mail came from a noreply address so\tyour reply will probably not be read." : "\t返信なしアドレスから送られているため、返信は読まれません。",
    "Message …" : "メッセージ…",
    "Saving draft …" : "下書きを保存しています",
    "Draft saved" : "下書きを保存しました。",
    "Uploading attachments …" : "添付ファイルをアップロード",
    "Sending …" : "送信中 …",
    "Error sending your message" : "メッセージ送信エラー",
    "Go back" : "戻る",
    "Retry" : "再試行",
    "Message sent!" : "へメッセージを送信しました！",
    "Reply sent!" : "返信送信！",
    "Write another message" : "他のメッセージを書く",
    "Send" : "送信",
    "Uploading {percent}% …" : "アップロード中 {percent}% …",
    "Upload attachment" : "添付ファイルをアップロードする",
    "Add attachment from Files" : "ファイルから添付ファイルの追加",
    "Choose a file to add as attachment" : "添付として追加するファイルを選択",
    "No messages in this folder" : "このフォルダーにメッセージはありません",
    "Draft: " : "下書き",
    "Mark read" : "既読にする",
    "Mark unread" : "未読にする",
    "Delete" : "削除",
    "Report this bug" : "バグを報告",
    "Loading messages" : "メッセージの読み込み中",
    "Not found" : "見つかりませんでした",
    "Could not load your message" : "あなたのメッセージを読み込めませんでした",
    "Import into calendar" : "カレンダーにインポート",
    "Download attachment" : "添付ファイルをダウンロード",
    "Save to Files" : "ファイルに保存",
    "Choose a folder to store the attachment in" : "添付ファイルを保存するフォルダーを選択",
    "Save all to Files" : "すべてファイルに保存",
    "Choose a folder to store the attachments in" : "添付ファイルを保存するフォルダを選択してください",
    "The images have been blocked to protect your privacy." : "画像はあなたのプライバシーを守るためにブロックされています。",
    "Show images from this\tsender" : "この\t送信者からの画像を表示する",
    "New message" : "新規メッセージ",
    "Settings" : "設定",
    "Edit" : "編集",
    "Add folder" : "フォルダーを追加",
    "Show all folders" : "すべてのフォルダーを表示",
    "Collapse folders" : "すべて展開",
    "Loading …" : "読み込み中...",
    "{total} messages ({unread} unread)" : "{total}件のメッセージ({unread}件未読)",
    "Mark all as read" : "すべて既読にする",
    "Mark all messages of this folder as read" : "このフォルダのすべてのメッセージを開封済みにする",
    "Add subfolder" : "サブフォルダを追加",
    "Could not load your draft" : "下書きを読み込めませんでした",
    "No message selected" : "メッセージが選択されていません。",
    "Signature" : "署名",
    "A signature will be added to the text of new and response messages." : "新規メッセージおよび応答メッセージのテキストに署名が追加されます。",
    "Account Settings" : "アカウント設定",
    "Mail server" : "メールサーバー",
    "Speed up your Mail experience with these quick shortcuts." : "ショートカットであなたのメール操作をスピードアップしてください。",
    "Compose new message" : "新しいメッセージを作成する",
    "Newer message" : "新しいメッセージ",
    "Older message" : "古いメッセージ",
    "Toggle star" : "スターを切り替え",
    "Toggle unread" : "未読を切り替え",
    "Search" : "検索",
    "Refresh" : "同期",
    "Connect your mail account" : "あなたのメールアカウントに接続",
    "{from}\n{subject}" : "{from}\n{subject}",
    "_%n new message \nfrom {from}_::_%n new messages \nfrom {from}_" : ["%n個の新しいメッセージ\nfrom{from}"],
    "Nextcloud Mail" : "Nextcloud メール",
    "All inboxes" : "すべての受信トレイ",
    "Could not load {tag}{name}{endtag}" : "{tag} {name} {endtag}を読み込めませんでした",
    "There was a problem loading {tag}{name}{endtag}" : "{tag}{name}{endtag} の読み込み中に問題が発生しました",
    "Could not load the desired message" : "目的のメッセージを読み込めませんでした",
    "Could not load the message" : "メッセージを読み込めませんでした",
    "Error loading message" : "メッセージ読み込みエラー",
    "Forwarding to %s" : "%s への転送",
    "Click here if you are not automatically redirected within the next few seconds." : "数秒以内に自動的にリダイレクトされない場合は、ここをクリックしてください。",
    "Redirect" : "リダイレクト",
    "The link leads to %s" : "リンクが %s につながります",
    "If you don’t want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "ページを開きたくない場合は、<a href=\"%s\">メール</a> に戻ることができます。",
    "Continue to %s" : "%s にリダイレクトする"
},
"nplurals=1; plural=0;");
